<!DOCTYPE html>
<html class="no-js seed-csp4" lang="en">
	<head>
		<meta charset="utf-8">
		<title>{Title}</title>
		{MetaDescription}
		<meta name="viewport" content="width=device-width, initial-scale=1.0">
		{Privacy}
		{Favicon}
		{Head}
		{CustomCSS}
	</head>
<body>
<div id="seed-csp4-page">
		<div id="seed-csp4-content">
			{Logo}
			{Headline}
			{Description}
		</div><!-- / #seed-csp4-content -->
{Append_HTML}
{Credit}
{Footer}
</div>
</body>
</html>

<!-- Coming Soon Page and Maintenance Mode by SeedProd. Learn more: http://www.seedprod.com -->
