@charset "UTF-8";
/*!
 * animate.css -http://daneden.me/animate
 * Version - 3.7.0
 * Licensed under the MIT license - http://opensource.org/licenses/MIT
 *
 * Copyright (c) 2018 Daniel Eden
 */
@-webkit-keyframes bounce {
  0%,
  20%,
  53%,
  80%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    -webkit-transform: translateZ(0);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    transform: translateZ(0);
  }
  40%,
  43% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    -webkit-transform: translate3d(0, -30px, 0);
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    transform: translate3d(0, -30px, 0);
  }
  70% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    -webkit-transform: translate3d(0, -15px, 0);
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    transform: translate3d(0, -15px, 0);
  }
  90% {
    -webkit-transform: translate3d(0, -4px, 0);
    transform: translate3d(0, -4px, 0);
  }
}
@keyframes bounce {
  0%,
  20%,
  53%,
  80%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    -webkit-transform: translateZ(0);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    transform: translateZ(0);
  }
  40%,
  43% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    -webkit-transform: translate3d(0, -30px, 0);
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    transform: translate3d(0, -30px, 0);
  }
  70% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    -webkit-transform: translate3d(0, -15px, 0);
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    transform: translate3d(0, -15px, 0);
  }
  90% {
    -webkit-transform: translate3d(0, -4px, 0);
    transform: translate3d(0, -4px, 0);
  }
}
.bounce {
  -webkit-animation-name: bounce;
  -webkit-transform-origin: center bottom;
  animation-name: bounce;
  transform-origin: center bottom;
}
@-webkit-keyframes flash {
  0%,
  50%,
  to {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
@keyframes flash {
  0%,
  50%,
  to {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
.flash {
  -webkit-animation-name: flash;
  animation-name: flash;
}
@-webkit-keyframes pulse {
  0% {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
  50% {
    -webkit-transform: scale3d(1.05, 1.05, 1.05);
    transform: scale3d(1.05, 1.05, 1.05);
  }
  to {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
}
@keyframes pulse {
  0% {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
  50% {
    -webkit-transform: scale3d(1.05, 1.05, 1.05);
    transform: scale3d(1.05, 1.05, 1.05);
  }
  to {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
}
.pulse {
  -webkit-animation-name: pulse;
  animation-name: pulse;
}
@-webkit-keyframes rubberBand {
  0% {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
  30% {
    -webkit-transform: scale3d(1.25, 0.75, 1);
    transform: scale3d(1.25, 0.75, 1);
  }
  40% {
    -webkit-transform: scale3d(0.75, 1.25, 1);
    transform: scale3d(0.75, 1.25, 1);
  }
  50% {
    -webkit-transform: scale3d(1.15, 0.85, 1);
    transform: scale3d(1.15, 0.85, 1);
  }
  65% {
    -webkit-transform: scale3d(0.95, 1.05, 1);
    transform: scale3d(0.95, 1.05, 1);
  }
  75% {
    -webkit-transform: scale3d(1.05, 0.95, 1);
    transform: scale3d(1.05, 0.95, 1);
  }
  to {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
}
@keyframes rubberBand {
  0% {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
  30% {
    -webkit-transform: scale3d(1.25, 0.75, 1);
    transform: scale3d(1.25, 0.75, 1);
  }
  40% {
    -webkit-transform: scale3d(0.75, 1.25, 1);
    transform: scale3d(0.75, 1.25, 1);
  }
  50% {
    -webkit-transform: scale3d(1.15, 0.85, 1);
    transform: scale3d(1.15, 0.85, 1);
  }
  65% {
    -webkit-transform: scale3d(0.95, 1.05, 1);
    transform: scale3d(0.95, 1.05, 1);
  }
  75% {
    -webkit-transform: scale3d(1.05, 0.95, 1);
    transform: scale3d(1.05, 0.95, 1);
  }
  to {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
}
.rubberBand {
  -webkit-animation-name: rubberBand;
  animation-name: rubberBand;
}
@-webkit-keyframes shake {
  0%,
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0);
  }
  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0);
  }
}
@keyframes shake {
  0%,
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0);
  }
  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0);
  }
}
.shake {
  -webkit-animation-name: shake;
  animation-name: shake;
}
@-webkit-keyframes headShake {
  0% {
    -webkit-transform: translateX(0);
    transform: translateX(0);
  }
  6.5% {
    -webkit-transform: translateX(-6px) rotateY(-9deg);
    transform: translateX(-6px) rotateY(-9deg);
  }
  18.5% {
    -webkit-transform: translateX(5px) rotateY(7deg);
    transform: translateX(5px) rotateY(7deg);
  }
  31.5% {
    -webkit-transform: translateX(-3px) rotateY(-5deg);
    transform: translateX(-3px) rotateY(-5deg);
  }
  43.5% {
    -webkit-transform: translateX(2px) rotateY(3deg);
    transform: translateX(2px) rotateY(3deg);
  }
  50% {
    -webkit-transform: translateX(0);
    transform: translateX(0);
  }
}
@keyframes headShake {
  0% {
    -webkit-transform: translateX(0);
    transform: translateX(0);
  }
  6.5% {
    -webkit-transform: translateX(-6px) rotateY(-9deg);
    transform: translateX(-6px) rotateY(-9deg);
  }
  18.5% {
    -webkit-transform: translateX(5px) rotateY(7deg);
    transform: translateX(5px) rotateY(7deg);
  }
  31.5% {
    -webkit-transform: translateX(-3px) rotateY(-5deg);
    transform: translateX(-3px) rotateY(-5deg);
  }
  43.5% {
    -webkit-transform: translateX(2px) rotateY(3deg);
    transform: translateX(2px) rotateY(3deg);
  }
  50% {
    -webkit-transform: translateX(0);
    transform: translateX(0);
  }
}
.headShake {
  -webkit-animation-name: headShake;
  -webkit-animation-timing-function: ease-in-out;
  animation-name: headShake;
  animation-timing-function: ease-in-out;
}
@-webkit-keyframes swing {
  20% {
    -webkit-transform: rotate(15deg);
    transform: rotate(15deg);
  }
  40% {
    -webkit-transform: rotate(-10deg);
    transform: rotate(-10deg);
  }
  60% {
    -webkit-transform: rotate(5deg);
    transform: rotate(5deg);
  }
  80% {
    -webkit-transform: rotate(-5deg);
    transform: rotate(-5deg);
  }
  to {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
}
@keyframes swing {
  20% {
    -webkit-transform: rotate(15deg);
    transform: rotate(15deg);
  }
  40% {
    -webkit-transform: rotate(-10deg);
    transform: rotate(-10deg);
  }
  60% {
    -webkit-transform: rotate(5deg);
    transform: rotate(5deg);
  }
  80% {
    -webkit-transform: rotate(-5deg);
    transform: rotate(-5deg);
  }
  to {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
}
.swing {
  -webkit-animation-name: swing;
  -webkit-transform-origin: top center;
  animation-name: swing;
  transform-origin: top center;
}
@-webkit-keyframes tada {
  0% {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
  10%,
  20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9) rotate(-3deg);
    transform: scale3d(0.9, 0.9, 0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate(3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate(-3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate(-3deg);
  }
  to {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
}
@keyframes tada {
  0% {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
  10%,
  20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9) rotate(-3deg);
    transform: scale3d(0.9, 0.9, 0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate(3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate(-3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate(-3deg);
  }
  to {
    -webkit-transform: scaleX(1);
    transform: scaleX(1);
  }
}
.tada {
  -webkit-animation-name: tada;
  animation-name: tada;
}
@-webkit-keyframes wobble {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  15% {
    -webkit-transform: translate3d(-25%, 0, 0) rotate(-5deg);
    transform: translate3d(-25%, 0, 0) rotate(-5deg);
  }
  30% {
    -webkit-transform: translate3d(20%, 0, 0) rotate(3deg);
    transform: translate3d(20%, 0, 0) rotate(3deg);
  }
  45% {
    -webkit-transform: translate3d(-15%, 0, 0) rotate(-3deg);
    transform: translate3d(-15%, 0, 0) rotate(-3deg);
  }
  60% {
    -webkit-transform: translate3d(10%, 0, 0) rotate(2deg);
    transform: translate3d(10%, 0, 0) rotate(2deg);
  }
  75% {
    -webkit-transform: translate3d(-5%, 0, 0) rotate(-1deg);
    transform: translate3d(-5%, 0, 0) rotate(-1deg);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes wobble {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  15% {
    -webkit-transform: translate3d(-25%, 0, 0) rotate(-5deg);
    transform: translate3d(-25%, 0, 0) rotate(-5deg);
  }
  30% {
    -webkit-transform: translate3d(20%, 0, 0) rotate(3deg);
    transform: translate3d(20%, 0, 0) rotate(3deg);
  }
  45% {
    -webkit-transform: translate3d(-15%, 0, 0) rotate(-3deg);
    transform: translate3d(-15%, 0, 0) rotate(-3deg);
  }
  60% {
    -webkit-transform: translate3d(10%, 0, 0) rotate(2deg);
    transform: translate3d(10%, 0, 0) rotate(2deg);
  }
  75% {
    -webkit-transform: translate3d(-5%, 0, 0) rotate(-1deg);
    transform: translate3d(-5%, 0, 0) rotate(-1deg);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.wobble {
  -webkit-animation-name: wobble;
  animation-name: wobble;
}
@-webkit-keyframes jello {
  0%,
  11.1%,
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  22.2% {
    -webkit-transform: skewX(-12.5deg) skewY(-12.5deg);
    transform: skewX(-12.5deg) skewY(-12.5deg);
  }
  33.3% {
    -webkit-transform: skewX(6.25deg) skewY(6.25deg);
    transform: skewX(6.25deg) skewY(6.25deg);
  }
  44.4% {
    -webkit-transform: skewX(-3.125deg) skewY(-3.125deg);
    transform: skewX(-3.125deg) skewY(-3.125deg);
  }
  55.5% {
    -webkit-transform: skewX(1.5625deg) skewY(1.5625deg);
    transform: skewX(1.5625deg) skewY(1.5625deg);
  }
  66.6% {
    -webkit-transform: skewX(-0.78125deg) skewY(-0.78125deg);
    transform: skewX(-0.78125deg) skewY(-0.78125deg);
  }
  77.7% {
    -webkit-transform: skewX(0.390625deg) skewY(0.390625deg);
    transform: skewX(0.390625deg) skewY(0.390625deg);
  }
  88.8% {
    -webkit-transform: skewX(-0.1953125deg) skewY(-0.1953125deg);
    transform: skewX(-0.1953125deg) skewY(-0.1953125deg);
  }
}
@keyframes jello {
  0%,
  11.1%,
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  22.2% {
    -webkit-transform: skewX(-12.5deg) skewY(-12.5deg);
    transform: skewX(-12.5deg) skewY(-12.5deg);
  }
  33.3% {
    -webkit-transform: skewX(6.25deg) skewY(6.25deg);
    transform: skewX(6.25deg) skewY(6.25deg);
  }
  44.4% {
    -webkit-transform: skewX(-3.125deg) skewY(-3.125deg);
    transform: skewX(-3.125deg) skewY(-3.125deg);
  }
  55.5% {
    -webkit-transform: skewX(1.5625deg) skewY(1.5625deg);
    transform: skewX(1.5625deg) skewY(1.5625deg);
  }
  66.6% {
    -webkit-transform: skewX(-0.78125deg) skewY(-0.78125deg);
    transform: skewX(-0.78125deg) skewY(-0.78125deg);
  }
  77.7% {
    -webkit-transform: skewX(0.390625deg) skewY(0.390625deg);
    transform: skewX(0.390625deg) skewY(0.390625deg);
  }
  88.8% {
    -webkit-transform: skewX(-0.1953125deg) skewY(-0.1953125deg);
    transform: skewX(-0.1953125deg) skewY(-0.1953125deg);
  }
}
.jello {
  -webkit-animation-name: jello;
  -webkit-transform-origin: center;
  animation-name: jello;
  transform-origin: center;
}
@-webkit-keyframes heartBeat {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
  14% {
    -webkit-transform: scale(1.3);
    transform: scale(1.3);
  }
  28% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
  42% {
    -webkit-transform: scale(1.3);
    transform: scale(1.3);
  }
  70% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
}
@keyframes heartBeat {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
  14% {
    -webkit-transform: scale(1.3);
    transform: scale(1.3);
  }
  28% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
  42% {
    -webkit-transform: scale(1.3);
    transform: scale(1.3);
  }
  70% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
}
.heartBeat {
  -webkit-animation-duration: 1.3s;
  -webkit-animation-name: heartBeat;
  -webkit-animation-timing-function: ease-in-out;
  animation-duration: 1.3s;
  animation-name: heartBeat;
  animation-timing-function: ease-in-out;
}
@-webkit-keyframes bounceIn {
  0%,
  20%,
  40%,
  60%,
  80%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
  20% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1);
  }
  40% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9);
  }
  60% {
    -webkit-transform: scale3d(1.03, 1.03, 1.03);
    opacity: 1;
    transform: scale3d(1.03, 1.03, 1.03);
  }
  80% {
    -webkit-transform: scale3d(0.97, 0.97, 0.97);
    transform: scale3d(0.97, 0.97, 0.97);
  }
  to {
    -webkit-transform: scaleX(1);
    opacity: 1;
    transform: scaleX(1);
  }
}
@keyframes bounceIn {
  0%,
  20%,
  40%,
  60%,
  80%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
  20% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1);
  }
  40% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9);
  }
  60% {
    -webkit-transform: scale3d(1.03, 1.03, 1.03);
    opacity: 1;
    transform: scale3d(1.03, 1.03, 1.03);
  }
  80% {
    -webkit-transform: scale3d(0.97, 0.97, 0.97);
    transform: scale3d(0.97, 0.97, 0.97);
  }
  to {
    -webkit-transform: scaleX(1);
    opacity: 1;
    transform: scaleX(1);
  }
}
.bounceIn {
  -webkit-animation-duration: 0.75s;
  -webkit-animation-name: bounceIn;
  animation-duration: 0.75s;
  animation-name: bounceIn;
}
@-webkit-keyframes bounceInDown {
  0%,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: translate3d(0, -3000px, 0);
    opacity: 0;
    transform: translate3d(0, -3000px, 0);
  }
  60% {
    -webkit-transform: translate3d(0, 25px, 0);
    opacity: 1;
    transform: translate3d(0, 25px, 0);
  }
  75% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0);
  }
  90% {
    -webkit-transform: translate3d(0, 5px, 0);
    transform: translate3d(0, 5px, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes bounceInDown {
  0%,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: translate3d(0, -3000px, 0);
    opacity: 0;
    transform: translate3d(0, -3000px, 0);
  }
  60% {
    -webkit-transform: translate3d(0, 25px, 0);
    opacity: 1;
    transform: translate3d(0, 25px, 0);
  }
  75% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0);
  }
  90% {
    -webkit-transform: translate3d(0, 5px, 0);
    transform: translate3d(0, 5px, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.bounceInDown {
  -webkit-animation-name: bounceInDown;
  animation-name: bounceInDown;
}
@-webkit-keyframes bounceInLeft {
  0%,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: translate3d(-3000px, 0, 0);
    opacity: 0;
    transform: translate3d(-3000px, 0, 0);
  }
  60% {
    -webkit-transform: translate3d(25px, 0, 0);
    opacity: 1;
    transform: translate3d(25px, 0, 0);
  }
  75% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0);
  }
  90% {
    -webkit-transform: translate3d(5px, 0, 0);
    transform: translate3d(5px, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes bounceInLeft {
  0%,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: translate3d(-3000px, 0, 0);
    opacity: 0;
    transform: translate3d(-3000px, 0, 0);
  }
  60% {
    -webkit-transform: translate3d(25px, 0, 0);
    opacity: 1;
    transform: translate3d(25px, 0, 0);
  }
  75% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0);
  }
  90% {
    -webkit-transform: translate3d(5px, 0, 0);
    transform: translate3d(5px, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.bounceInLeft {
  -webkit-animation-name: bounceInLeft;
  animation-name: bounceInLeft;
}
@-webkit-keyframes bounceInRight {
  0%,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: translate3d(3000px, 0, 0);
    opacity: 0;
    transform: translate3d(3000px, 0, 0);
  }
  60% {
    -webkit-transform: translate3d(-25px, 0, 0);
    opacity: 1;
    transform: translate3d(-25px, 0, 0);
  }
  75% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0);
  }
  90% {
    -webkit-transform: translate3d(-5px, 0, 0);
    transform: translate3d(-5px, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes bounceInRight {
  0%,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: translate3d(3000px, 0, 0);
    opacity: 0;
    transform: translate3d(3000px, 0, 0);
  }
  60% {
    -webkit-transform: translate3d(-25px, 0, 0);
    opacity: 1;
    transform: translate3d(-25px, 0, 0);
  }
  75% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0);
  }
  90% {
    -webkit-transform: translate3d(-5px, 0, 0);
    transform: translate3d(-5px, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.bounceInRight {
  -webkit-animation-name: bounceInRight;
  animation-name: bounceInRight;
}
@-webkit-keyframes bounceInUp {
  0%,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: translate3d(0, 3000px, 0);
    opacity: 0;
    transform: translate3d(0, 3000px, 0);
  }
  60% {
    -webkit-transform: translate3d(0, -20px, 0);
    opacity: 1;
    transform: translate3d(0, -20px, 0);
  }
  75% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0);
  }
  90% {
    -webkit-transform: translate3d(0, -5px, 0);
    transform: translate3d(0, -5px, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes bounceInUp {
  0%,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    -webkit-transform: translate3d(0, 3000px, 0);
    opacity: 0;
    transform: translate3d(0, 3000px, 0);
  }
  60% {
    -webkit-transform: translate3d(0, -20px, 0);
    opacity: 1;
    transform: translate3d(0, -20px, 0);
  }
  75% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0);
  }
  90% {
    -webkit-transform: translate3d(0, -5px, 0);
    transform: translate3d(0, -5px, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.bounceInUp {
  -webkit-animation-name: bounceInUp;
  animation-name: bounceInUp;
}
@-webkit-keyframes bounceOut {
  20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9);
  }
  50%,
  55% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    opacity: 1;
    transform: scale3d(1.1, 1.1, 1.1);
  }
  to {
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
}
@keyframes bounceOut {
  20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9);
  }
  50%,
  55% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    opacity: 1;
    transform: scale3d(1.1, 1.1, 1.1);
  }
  to {
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
}
.bounceOut {
  -webkit-animation-duration: 0.75s;
  -webkit-animation-name: bounceOut;
  animation-duration: 0.75s;
  animation-name: bounceOut;
}
@-webkit-keyframes bounceOutDown {
  20% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0);
  }
  40%,
  45% {
    -webkit-transform: translate3d(0, -20px, 0);
    opacity: 1;
    transform: translate3d(0, -20px, 0);
  }
  to {
    -webkit-transform: translate3d(0, 2000px, 0);
    opacity: 0;
    transform: translate3d(0, 2000px, 0);
  }
}
@keyframes bounceOutDown {
  20% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0);
  }
  40%,
  45% {
    -webkit-transform: translate3d(0, -20px, 0);
    opacity: 1;
    transform: translate3d(0, -20px, 0);
  }
  to {
    -webkit-transform: translate3d(0, 2000px, 0);
    opacity: 0;
    transform: translate3d(0, 2000px, 0);
  }
}
.bounceOutDown {
  -webkit-animation-name: bounceOutDown;
  animation-name: bounceOutDown;
}
@-webkit-keyframes bounceOutLeft {
  20% {
    -webkit-transform: translate3d(20px, 0, 0);
    opacity: 1;
    transform: translate3d(20px, 0, 0);
  }
  to {
    -webkit-transform: translate3d(-2000px, 0, 0);
    opacity: 0;
    transform: translate3d(-2000px, 0, 0);
  }
}
@keyframes bounceOutLeft {
  20% {
    -webkit-transform: translate3d(20px, 0, 0);
    opacity: 1;
    transform: translate3d(20px, 0, 0);
  }
  to {
    -webkit-transform: translate3d(-2000px, 0, 0);
    opacity: 0;
    transform: translate3d(-2000px, 0, 0);
  }
}
.bounceOutLeft {
  -webkit-animation-name: bounceOutLeft;
  animation-name: bounceOutLeft;
}
@-webkit-keyframes bounceOutRight {
  20% {
    -webkit-transform: translate3d(-20px, 0, 0);
    opacity: 1;
    transform: translate3d(-20px, 0, 0);
  }
  to {
    -webkit-transform: translate3d(2000px, 0, 0);
    opacity: 0;
    transform: translate3d(2000px, 0, 0);
  }
}
@keyframes bounceOutRight {
  20% {
    -webkit-transform: translate3d(-20px, 0, 0);
    opacity: 1;
    transform: translate3d(-20px, 0, 0);
  }
  to {
    -webkit-transform: translate3d(2000px, 0, 0);
    opacity: 0;
    transform: translate3d(2000px, 0, 0);
  }
}
.bounceOutRight {
  -webkit-animation-name: bounceOutRight;
  animation-name: bounceOutRight;
}
@-webkit-keyframes bounceOutUp {
  20% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0);
  }
  40%,
  45% {
    -webkit-transform: translate3d(0, 20px, 0);
    opacity: 1;
    transform: translate3d(0, 20px, 0);
  }
  to {
    -webkit-transform: translate3d(0, -2000px, 0);
    opacity: 0;
    transform: translate3d(0, -2000px, 0);
  }
}
@keyframes bounceOutUp {
  20% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0);
  }
  40%,
  45% {
    -webkit-transform: translate3d(0, 20px, 0);
    opacity: 1;
    transform: translate3d(0, 20px, 0);
  }
  to {
    -webkit-transform: translate3d(0, -2000px, 0);
    opacity: 0;
    transform: translate3d(0, -2000px, 0);
  }
}
.bounceOutUp {
  -webkit-animation-name: bounceOutUp;
  animation-name: bounceOutUp;
}
@-webkit-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@keyframes fadeIn {
  0% {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
.fadeIn {
  -webkit-animation-name: fadeIn;
  animation-name: fadeIn;
}
@-webkit-keyframes fadeInDown {
  0% {
    -webkit-transform: translate3d(0, -100%, 0);
    opacity: 0;
    transform: translate3d(0, -100%, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes fadeInDown {
  0% {
    -webkit-transform: translate3d(0, -100%, 0);
    opacity: 0;
    transform: translate3d(0, -100%, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.fadeInDown {
  -webkit-animation-name: fadeInDown;
  animation-name: fadeInDown;
}
@-webkit-keyframes fadeInDownBig {
  0% {
    -webkit-transform: translate3d(0, -2000px, 0);
    opacity: 0;
    transform: translate3d(0, -2000px, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes fadeInDownBig {
  0% {
    -webkit-transform: translate3d(0, -2000px, 0);
    opacity: 0;
    transform: translate3d(0, -2000px, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.fadeInDownBig {
  -webkit-animation-name: fadeInDownBig;
  animation-name: fadeInDownBig;
}
@-webkit-keyframes fadeInLeft {
  0% {
    -webkit-transform: translate3d(-100%, 0, 0);
    opacity: 0;
    transform: translate3d(-100%, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes fadeInLeft {
  0% {
    -webkit-transform: translate3d(-100%, 0, 0);
    opacity: 0;
    transform: translate3d(-100%, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.fadeInLeft {
  -webkit-animation-name: fadeInLeft;
  animation-name: fadeInLeft;
}
@-webkit-keyframes fadeInLeftBig {
  0% {
    -webkit-transform: translate3d(-2000px, 0, 0);
    opacity: 0;
    transform: translate3d(-2000px, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes fadeInLeftBig {
  0% {
    -webkit-transform: translate3d(-2000px, 0, 0);
    opacity: 0;
    transform: translate3d(-2000px, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.fadeInLeftBig {
  -webkit-animation-name: fadeInLeftBig;
  animation-name: fadeInLeftBig;
}
@-webkit-keyframes fadeInRight {
  0% {
    -webkit-transform: translate3d(100%, 0, 0);
    opacity: 0;
    transform: translate3d(100%, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes fadeInRight {
  0% {
    -webkit-transform: translate3d(100%, 0, 0);
    opacity: 0;
    transform: translate3d(100%, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.fadeInRight {
  -webkit-animation-name: fadeInRight;
  animation-name: fadeInRight;
}
@-webkit-keyframes fadeInRightBig {
  0% {
    -webkit-transform: translate3d(2000px, 0, 0);
    opacity: 0;
    transform: translate3d(2000px, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes fadeInRightBig {
  0% {
    -webkit-transform: translate3d(2000px, 0, 0);
    opacity: 0;
    transform: translate3d(2000px, 0, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.fadeInRightBig {
  -webkit-animation-name: fadeInRightBig;
  animation-name: fadeInRightBig;
}
@-webkit-keyframes fadeInUp {
  0% {
    -webkit-transform: translate3d(0, 100%, 0);
    opacity: 0;
    transform: translate3d(0, 100%, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes fadeInUp {
  0% {
    -webkit-transform: translate3d(0, 100%, 0);
    opacity: 0;
    transform: translate3d(0, 100%, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.fadeInUp {
  -webkit-animation-name: fadeInUp;
  animation-name: fadeInUp;
}
@-webkit-keyframes fadeInUpBig {
  0% {
    -webkit-transform: translate3d(0, 2000px, 0);
    opacity: 0;
    transform: translate3d(0, 2000px, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes fadeInUpBig {
  0% {
    -webkit-transform: translate3d(0, 2000px, 0);
    opacity: 0;
    transform: translate3d(0, 2000px, 0);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.fadeInUpBig {
  -webkit-animation-name: fadeInUpBig;
  animation-name: fadeInUpBig;
}
@-webkit-keyframes fadeOut {
  0% {
    opacity: 1;
  }
  to {
    opacity: 0;
  }
}
@keyframes fadeOut {
  0% {
    opacity: 1;
  }
  to {
    opacity: 0;
  }
}
.fadeOut {
  -webkit-animation-name: fadeOut;
  animation-name: fadeOut;
}
@-webkit-keyframes fadeOutDown {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(0, 100%, 0);
    opacity: 0;
    transform: translate3d(0, 100%, 0);
  }
}
@keyframes fadeOutDown {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(0, 100%, 0);
    opacity: 0;
    transform: translate3d(0, 100%, 0);
  }
}
.fadeOutDown {
  -webkit-animation-name: fadeOutDown;
  animation-name: fadeOutDown;
}
@-webkit-keyframes fadeOutDownBig {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(0, 2000px, 0);
    opacity: 0;
    transform: translate3d(0, 2000px, 0);
  }
}
@keyframes fadeOutDownBig {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(0, 2000px, 0);
    opacity: 0;
    transform: translate3d(0, 2000px, 0);
  }
}
.fadeOutDownBig {
  -webkit-animation-name: fadeOutDownBig;
  animation-name: fadeOutDownBig;
}
@-webkit-keyframes fadeOutLeft {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(-100%, 0, 0);
    opacity: 0;
    transform: translate3d(-100%, 0, 0);
  }
}
@keyframes fadeOutLeft {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(-100%, 0, 0);
    opacity: 0;
    transform: translate3d(-100%, 0, 0);
  }
}
.fadeOutLeft {
  -webkit-animation-name: fadeOutLeft;
  animation-name: fadeOutLeft;
}
@-webkit-keyframes fadeOutLeftBig {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(-2000px, 0, 0);
    opacity: 0;
    transform: translate3d(-2000px, 0, 0);
  }
}
@keyframes fadeOutLeftBig {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(-2000px, 0, 0);
    opacity: 0;
    transform: translate3d(-2000px, 0, 0);
  }
}
.fadeOutLeftBig {
  -webkit-animation-name: fadeOutLeftBig;
  animation-name: fadeOutLeftBig;
}
@-webkit-keyframes fadeOutRight {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(100%, 0, 0);
    opacity: 0;
    transform: translate3d(100%, 0, 0);
  }
}
@keyframes fadeOutRight {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(100%, 0, 0);
    opacity: 0;
    transform: translate3d(100%, 0, 0);
  }
}
.fadeOutRight {
  -webkit-animation-name: fadeOutRight;
  animation-name: fadeOutRight;
}
@-webkit-keyframes fadeOutRightBig {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(2000px, 0, 0);
    opacity: 0;
    transform: translate3d(2000px, 0, 0);
  }
}
@keyframes fadeOutRightBig {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(2000px, 0, 0);
    opacity: 0;
    transform: translate3d(2000px, 0, 0);
  }
}
.fadeOutRightBig {
  -webkit-animation-name: fadeOutRightBig;
  animation-name: fadeOutRightBig;
}
@-webkit-keyframes fadeOutUp {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(0, -100%, 0);
    opacity: 0;
    transform: translate3d(0, -100%, 0);
  }
}
@keyframes fadeOutUp {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(0, -100%, 0);
    opacity: 0;
    transform: translate3d(0, -100%, 0);
  }
}
.fadeOutUp {
  -webkit-animation-name: fadeOutUp;
  animation-name: fadeOutUp;
}
@-webkit-keyframes fadeOutUpBig {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(0, -2000px, 0);
    opacity: 0;
    transform: translate3d(0, -2000px, 0);
  }
}
@keyframes fadeOutUpBig {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(0, -2000px, 0);
    opacity: 0;
    transform: translate3d(0, -2000px, 0);
  }
}
.fadeOutUpBig {
  -webkit-animation-name: fadeOutUpBig;
  animation-name: fadeOutUpBig;
}
@-webkit-keyframes flip {
  0% {
    -webkit-animation-timing-function: ease-out;
    -webkit-transform: perspective(400px) scaleX(1) translateZ(0) rotateY(-1turn);
    animation-timing-function: ease-out;
    transform: perspective(400px) scaleX(1) translateZ(0) rotateY(-1turn);
  }
  40% {
    -webkit-animation-timing-function: ease-out;
    -webkit-transform: perspective(400px) scaleX(1) translateZ(150px) rotateY(-190deg);
    animation-timing-function: ease-out;
    transform: perspective(400px) scaleX(1) translateZ(150px) rotateY(-190deg);
  }
  50% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) scaleX(1) translateZ(150px) rotateY(-170deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) scaleX(1) translateZ(150px) rotateY(-170deg);
  }
  80% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) scale3d(0.95, 0.95, 0.95) translateZ(0) rotateY(0deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) scale3d(0.95, 0.95, 0.95) translateZ(0) rotateY(0deg);
  }
  to {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) scaleX(1) translateZ(0) rotateY(0deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) scaleX(1) translateZ(0) rotateY(0deg);
  }
}
@keyframes flip {
  0% {
    -webkit-animation-timing-function: ease-out;
    -webkit-transform: perspective(400px) scaleX(1) translateZ(0) rotateY(-1turn);
    animation-timing-function: ease-out;
    transform: perspective(400px) scaleX(1) translateZ(0) rotateY(-1turn);
  }
  40% {
    -webkit-animation-timing-function: ease-out;
    -webkit-transform: perspective(400px) scaleX(1) translateZ(150px) rotateY(-190deg);
    animation-timing-function: ease-out;
    transform: perspective(400px) scaleX(1) translateZ(150px) rotateY(-190deg);
  }
  50% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) scaleX(1) translateZ(150px) rotateY(-170deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) scaleX(1) translateZ(150px) rotateY(-170deg);
  }
  80% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) scale3d(0.95, 0.95, 0.95) translateZ(0) rotateY(0deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) scale3d(0.95, 0.95, 0.95) translateZ(0) rotateY(0deg);
  }
  to {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) scaleX(1) translateZ(0) rotateY(0deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) scaleX(1) translateZ(0) rotateY(0deg);
  }
}
.animated.flip {
  -webkit-animation-name: flip;
  -webkit-backface-visibility: visible;
  animation-name: flip;
  backface-visibility: visible;
}
@-webkit-keyframes flipInX {
  0% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) rotateX(90deg);
    animation-timing-function: ease-in;
    opacity: 0;
    transform: perspective(400px) rotateX(90deg);
  }
  40% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) rotateX(-20deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) rotateX(-20deg);
  }
  60% {
    -webkit-transform: perspective(400px) rotateX(10deg);
    opacity: 1;
    transform: perspective(400px) rotateX(10deg);
  }
  80% {
    -webkit-transform: perspective(400px) rotateX(-5deg);
    transform: perspective(400px) rotateX(-5deg);
  }
  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
}
@keyframes flipInX {
  0% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) rotateX(90deg);
    animation-timing-function: ease-in;
    opacity: 0;
    transform: perspective(400px) rotateX(90deg);
  }
  40% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) rotateX(-20deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) rotateX(-20deg);
  }
  60% {
    -webkit-transform: perspective(400px) rotateX(10deg);
    opacity: 1;
    transform: perspective(400px) rotateX(10deg);
  }
  80% {
    -webkit-transform: perspective(400px) rotateX(-5deg);
    transform: perspective(400px) rotateX(-5deg);
  }
  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
}
.flipInX {
  -webkit-animation-name: flipInX;
  -webkit-backface-visibility: visible!important;
  animation-name: flipInX;
  backface-visibility: visible !important;
}
@-webkit-keyframes flipInY {
  0% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) rotateY(90deg);
    animation-timing-function: ease-in;
    opacity: 0;
    transform: perspective(400px) rotateY(90deg);
  }
  40% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) rotateY(-20deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) rotateY(-20deg);
  }
  60% {
    -webkit-transform: perspective(400px) rotateY(10deg);
    opacity: 1;
    transform: perspective(400px) rotateY(10deg);
  }
  80% {
    -webkit-transform: perspective(400px) rotateY(-5deg);
    transform: perspective(400px) rotateY(-5deg);
  }
  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
}
@keyframes flipInY {
  0% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) rotateY(90deg);
    animation-timing-function: ease-in;
    opacity: 0;
    transform: perspective(400px) rotateY(90deg);
  }
  40% {
    -webkit-animation-timing-function: ease-in;
    -webkit-transform: perspective(400px) rotateY(-20deg);
    animation-timing-function: ease-in;
    transform: perspective(400px) rotateY(-20deg);
  }
  60% {
    -webkit-transform: perspective(400px) rotateY(10deg);
    opacity: 1;
    transform: perspective(400px) rotateY(10deg);
  }
  80% {
    -webkit-transform: perspective(400px) rotateY(-5deg);
    transform: perspective(400px) rotateY(-5deg);
  }
  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
}
.flipInY {
  -webkit-animation-name: flipInY;
  -webkit-backface-visibility: visible!important;
  animation-name: flipInY;
  backface-visibility: visible !important;
}
@-webkit-keyframes flipOutX {
  0% {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
  30% {
    -webkit-transform: perspective(400px) rotateX(-20deg);
    opacity: 1;
    transform: perspective(400px) rotateX(-20deg);
  }
  to {
    -webkit-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
    transform: perspective(400px) rotateX(90deg);
  }
}
@keyframes flipOutX {
  0% {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
  30% {
    -webkit-transform: perspective(400px) rotateX(-20deg);
    opacity: 1;
    transform: perspective(400px) rotateX(-20deg);
  }
  to {
    -webkit-transform: perspective(400px) rotateX(90deg);
    opacity: 0;
    transform: perspective(400px) rotateX(90deg);
  }
}
.flipOutX {
  -webkit-animation-duration: 0.75s;
  -webkit-animation-name: flipOutX;
  -webkit-backface-visibility: visible!important;
  animation-duration: 0.75s;
  animation-name: flipOutX;
  backface-visibility: visible !important;
}
@-webkit-keyframes flipOutY {
  0% {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
  30% {
    -webkit-transform: perspective(400px) rotateY(-15deg);
    opacity: 1;
    transform: perspective(400px) rotateY(-15deg);
  }
  to {
    -webkit-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
    transform: perspective(400px) rotateY(90deg);
  }
}
@keyframes flipOutY {
  0% {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
  30% {
    -webkit-transform: perspective(400px) rotateY(-15deg);
    opacity: 1;
    transform: perspective(400px) rotateY(-15deg);
  }
  to {
    -webkit-transform: perspective(400px) rotateY(90deg);
    opacity: 0;
    transform: perspective(400px) rotateY(90deg);
  }
}
.flipOutY {
  -webkit-animation-duration: 0.75s;
  -webkit-animation-name: flipOutY;
  -webkit-backface-visibility: visible!important;
  animation-duration: 0.75s;
  animation-name: flipOutY;
  backface-visibility: visible !important;
}
@-webkit-keyframes lightSpeedIn {
  0% {
    -webkit-transform: translate3d(100%, 0, 0) skewX(-30deg);
    opacity: 0;
    transform: translate3d(100%, 0, 0) skewX(-30deg);
  }
  60% {
    -webkit-transform: skewX(20deg);
    opacity: 1;
    transform: skewX(20deg);
  }
  80% {
    -webkit-transform: skewX(-5deg);
    transform: skewX(-5deg);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes lightSpeedIn {
  0% {
    -webkit-transform: translate3d(100%, 0, 0) skewX(-30deg);
    opacity: 0;
    transform: translate3d(100%, 0, 0) skewX(-30deg);
  }
  60% {
    -webkit-transform: skewX(20deg);
    opacity: 1;
    transform: skewX(20deg);
  }
  80% {
    -webkit-transform: skewX(-5deg);
    transform: skewX(-5deg);
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.lightSpeedIn {
  -webkit-animation-name: lightSpeedIn;
  -webkit-animation-timing-function: ease-out;
  animation-name: lightSpeedIn;
  animation-timing-function: ease-out;
}
@-webkit-keyframes lightSpeedOut {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(100%, 0, 0) skewX(30deg);
    opacity: 0;
    transform: translate3d(100%, 0, 0) skewX(30deg);
  }
}
@keyframes lightSpeedOut {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(100%, 0, 0) skewX(30deg);
    opacity: 0;
    transform: translate3d(100%, 0, 0) skewX(30deg);
  }
}
.lightSpeedOut {
  -webkit-animation-name: lightSpeedOut;
  -webkit-animation-timing-function: ease-in;
  animation-name: lightSpeedOut;
  animation-timing-function: ease-in;
}
@-webkit-keyframes rotateIn {
  0% {
    -webkit-transform: rotate(-200deg);
    -webkit-transform-origin: center;
    opacity: 0;
    transform: rotate(-200deg);
    transform-origin: center;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: center;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: center;
  }
}
@keyframes rotateIn {
  0% {
    -webkit-transform: rotate(-200deg);
    -webkit-transform-origin: center;
    opacity: 0;
    transform: rotate(-200deg);
    transform-origin: center;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: center;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: center;
  }
}
.rotateIn {
  -webkit-animation-name: rotateIn;
  animation-name: rotateIn;
}
@-webkit-keyframes rotateInDownLeft {
  0% {
    -webkit-transform: rotate(-45deg);
    -webkit-transform-origin: left bottom;
    opacity: 0;
    transform: rotate(-45deg);
    transform-origin: left bottom;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: left bottom;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: left bottom;
  }
}
@keyframes rotateInDownLeft {
  0% {
    -webkit-transform: rotate(-45deg);
    -webkit-transform-origin: left bottom;
    opacity: 0;
    transform: rotate(-45deg);
    transform-origin: left bottom;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: left bottom;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: left bottom;
  }
}
.rotateInDownLeft {
  -webkit-animation-name: rotateInDownLeft;
  animation-name: rotateInDownLeft;
}
@-webkit-keyframes rotateInDownRight {
  0% {
    -webkit-transform: rotate(45deg);
    -webkit-transform-origin: right bottom;
    opacity: 0;
    transform: rotate(45deg);
    transform-origin: right bottom;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: right bottom;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: right bottom;
  }
}
@keyframes rotateInDownRight {
  0% {
    -webkit-transform: rotate(45deg);
    -webkit-transform-origin: right bottom;
    opacity: 0;
    transform: rotate(45deg);
    transform-origin: right bottom;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: right bottom;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: right bottom;
  }
}
.rotateInDownRight {
  -webkit-animation-name: rotateInDownRight;
  animation-name: rotateInDownRight;
}
@-webkit-keyframes rotateInUpLeft {
  0% {
    -webkit-transform: rotate(45deg);
    -webkit-transform-origin: left bottom;
    opacity: 0;
    transform: rotate(45deg);
    transform-origin: left bottom;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: left bottom;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: left bottom;
  }
}
@keyframes rotateInUpLeft {
  0% {
    -webkit-transform: rotate(45deg);
    -webkit-transform-origin: left bottom;
    opacity: 0;
    transform: rotate(45deg);
    transform-origin: left bottom;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: left bottom;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: left bottom;
  }
}
.rotateInUpLeft {
  -webkit-animation-name: rotateInUpLeft;
  animation-name: rotateInUpLeft;
}
@-webkit-keyframes rotateInUpRight {
  0% {
    -webkit-transform: rotate(-90deg);
    -webkit-transform-origin: right bottom;
    opacity: 0;
    transform: rotate(-90deg);
    transform-origin: right bottom;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: right bottom;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: right bottom;
  }
}
@keyframes rotateInUpRight {
  0% {
    -webkit-transform: rotate(-90deg);
    -webkit-transform-origin: right bottom;
    opacity: 0;
    transform: rotate(-90deg);
    transform-origin: right bottom;
  }
  to {
    -webkit-transform: translateZ(0);
    -webkit-transform-origin: right bottom;
    opacity: 1;
    transform: translateZ(0);
    transform-origin: right bottom;
  }
}
.rotateInUpRight {
  -webkit-animation-name: rotateInUpRight;
  animation-name: rotateInUpRight;
}
@-webkit-keyframes rotateOut {
  0% {
    -webkit-transform-origin: center;
    opacity: 1;
    transform-origin: center;
  }
  to {
    -webkit-transform: rotate(200deg);
    -webkit-transform-origin: center;
    opacity: 0;
    transform: rotate(200deg);
    transform-origin: center;
  }
}
@keyframes rotateOut {
  0% {
    -webkit-transform-origin: center;
    opacity: 1;
    transform-origin: center;
  }
  to {
    -webkit-transform: rotate(200deg);
    -webkit-transform-origin: center;
    opacity: 0;
    transform: rotate(200deg);
    transform-origin: center;
  }
}
.rotateOut {
  -webkit-animation-name: rotateOut;
  animation-name: rotateOut;
}
@-webkit-keyframes rotateOutDownLeft {
  0% {
    -webkit-transform-origin: left bottom;
    opacity: 1;
    transform-origin: left bottom;
  }
  to {
    -webkit-transform: rotate(45deg);
    -webkit-transform-origin: left bottom;
    opacity: 0;
    transform: rotate(45deg);
    transform-origin: left bottom;
  }
}
@keyframes rotateOutDownLeft {
  0% {
    -webkit-transform-origin: left bottom;
    opacity: 1;
    transform-origin: left bottom;
  }
  to {
    -webkit-transform: rotate(45deg);
    -webkit-transform-origin: left bottom;
    opacity: 0;
    transform: rotate(45deg);
    transform-origin: left bottom;
  }
}
.rotateOutDownLeft {
  -webkit-animation-name: rotateOutDownLeft;
  animation-name: rotateOutDownLeft;
}
@-webkit-keyframes rotateOutDownRight {
  0% {
    -webkit-transform-origin: right bottom;
    opacity: 1;
    transform-origin: right bottom;
  }
  to {
    -webkit-transform: rotate(-45deg);
    -webkit-transform-origin: right bottom;
    opacity: 0;
    transform: rotate(-45deg);
    transform-origin: right bottom;
  }
}
@keyframes rotateOutDownRight {
  0% {
    -webkit-transform-origin: right bottom;
    opacity: 1;
    transform-origin: right bottom;
  }
  to {
    -webkit-transform: rotate(-45deg);
    -webkit-transform-origin: right bottom;
    opacity: 0;
    transform: rotate(-45deg);
    transform-origin: right bottom;
  }
}
.rotateOutDownRight {
  -webkit-animation-name: rotateOutDownRight;
  animation-name: rotateOutDownRight;
}
@-webkit-keyframes rotateOutUpLeft {
  0% {
    -webkit-transform-origin: left bottom;
    opacity: 1;
    transform-origin: left bottom;
  }
  to {
    -webkit-transform: rotate(-45deg);
    -webkit-transform-origin: left bottom;
    opacity: 0;
    transform: rotate(-45deg);
    transform-origin: left bottom;
  }
}
@keyframes rotateOutUpLeft {
  0% {
    -webkit-transform-origin: left bottom;
    opacity: 1;
    transform-origin: left bottom;
  }
  to {
    -webkit-transform: rotate(-45deg);
    -webkit-transform-origin: left bottom;
    opacity: 0;
    transform: rotate(-45deg);
    transform-origin: left bottom;
  }
}
.rotateOutUpLeft {
  -webkit-animation-name: rotateOutUpLeft;
  animation-name: rotateOutUpLeft;
}
@-webkit-keyframes rotateOutUpRight {
  0% {
    -webkit-transform-origin: right bottom;
    opacity: 1;
    transform-origin: right bottom;
  }
  to {
    -webkit-transform: rotate(90deg);
    -webkit-transform-origin: right bottom;
    opacity: 0;
    transform: rotate(90deg);
    transform-origin: right bottom;
  }
}
@keyframes rotateOutUpRight {
  0% {
    -webkit-transform-origin: right bottom;
    opacity: 1;
    transform-origin: right bottom;
  }
  to {
    -webkit-transform: rotate(90deg);
    -webkit-transform-origin: right bottom;
    opacity: 0;
    transform: rotate(90deg);
    transform-origin: right bottom;
  }
}
.rotateOutUpRight {
  -webkit-animation-name: rotateOutUpRight;
  animation-name: rotateOutUpRight;
}
@-webkit-keyframes hinge {
  0% {
    -webkit-animation-timing-function: ease-in-out;
    -webkit-transform-origin: top left;
    animation-timing-function: ease-in-out;
    transform-origin: top left;
  }
  20%,
  60% {
    -webkit-animation-timing-function: ease-in-out;
    -webkit-transform: rotate(80deg);
    -webkit-transform-origin: top left;
    animation-timing-function: ease-in-out;
    transform: rotate(80deg);
    transform-origin: top left;
  }
  40%,
  80% {
    -webkit-animation-timing-function: ease-in-out;
    -webkit-transform: rotate(60deg);
    -webkit-transform-origin: top left;
    animation-timing-function: ease-in-out;
    opacity: 1;
    transform: rotate(60deg);
    transform-origin: top left;
  }
  to {
    -webkit-transform: translate3d(0, 700px, 0);
    opacity: 0;
    transform: translate3d(0, 700px, 0);
  }
}
@keyframes hinge {
  0% {
    -webkit-animation-timing-function: ease-in-out;
    -webkit-transform-origin: top left;
    animation-timing-function: ease-in-out;
    transform-origin: top left;
  }
  20%,
  60% {
    -webkit-animation-timing-function: ease-in-out;
    -webkit-transform: rotate(80deg);
    -webkit-transform-origin: top left;
    animation-timing-function: ease-in-out;
    transform: rotate(80deg);
    transform-origin: top left;
  }
  40%,
  80% {
    -webkit-animation-timing-function: ease-in-out;
    -webkit-transform: rotate(60deg);
    -webkit-transform-origin: top left;
    animation-timing-function: ease-in-out;
    opacity: 1;
    transform: rotate(60deg);
    transform-origin: top left;
  }
  to {
    -webkit-transform: translate3d(0, 700px, 0);
    opacity: 0;
    transform: translate3d(0, 700px, 0);
  }
}
.hinge {
  -webkit-animation-duration: 2s;
  -webkit-animation-name: hinge;
  animation-duration: 2s;
  animation-name: hinge;
}
@-webkit-keyframes jackInTheBox {
  0% {
    -webkit-transform: scale(0.1) rotate(30deg);
    -webkit-transform-origin: center bottom;
    opacity: 0;
    transform: scale(0.1) rotate(30deg);
    transform-origin: center bottom;
  }
  50% {
    -webkit-transform: rotate(-10deg);
    transform: rotate(-10deg);
  }
  70% {
    -webkit-transform: rotate(3deg);
    transform: rotate(3deg);
  }
  to {
    -webkit-transform: scale(1);
    opacity: 1;
    transform: scale(1);
  }
}
@keyframes jackInTheBox {
  0% {
    -webkit-transform: scale(0.1) rotate(30deg);
    -webkit-transform-origin: center bottom;
    opacity: 0;
    transform: scale(0.1) rotate(30deg);
    transform-origin: center bottom;
  }
  50% {
    -webkit-transform: rotate(-10deg);
    transform: rotate(-10deg);
  }
  70% {
    -webkit-transform: rotate(3deg);
    transform: rotate(3deg);
  }
  to {
    -webkit-transform: scale(1);
    opacity: 1;
    transform: scale(1);
  }
}
.jackInTheBox {
  -webkit-animation-name: jackInTheBox;
  animation-name: jackInTheBox;
}
@-webkit-keyframes rollIn {
  0% {
    -webkit-transform: translate3d(-100%, 0, 0) rotate(-120deg);
    opacity: 0;
    transform: translate3d(-100%, 0, 0) rotate(-120deg);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
@keyframes rollIn {
  0% {
    -webkit-transform: translate3d(-100%, 0, 0) rotate(-120deg);
    opacity: 0;
    transform: translate3d(-100%, 0, 0) rotate(-120deg);
  }
  to {
    -webkit-transform: translateZ(0);
    opacity: 1;
    transform: translateZ(0);
  }
}
.rollIn {
  -webkit-animation-name: rollIn;
  animation-name: rollIn;
}
@-webkit-keyframes rollOut {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(100%, 0, 0) rotate(120deg);
    opacity: 0;
    transform: translate3d(100%, 0, 0) rotate(120deg);
  }
}
@keyframes rollOut {
  0% {
    opacity: 1;
  }
  to {
    -webkit-transform: translate3d(100%, 0, 0) rotate(120deg);
    opacity: 0;
    transform: translate3d(100%, 0, 0) rotate(120deg);
  }
}
.rollOut {
  -webkit-animation-name: rollOut;
  animation-name: rollOut;
}
@-webkit-keyframes zoomIn {
  0% {
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
  50% {
    opacity: 1;
  }
}
@keyframes zoomIn {
  0% {
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
  50% {
    opacity: 1;
  }
}
.zoomIn {
  -webkit-animation-name: zoomIn;
  animation-name: zoomIn;
}
@-webkit-keyframes zoomInDown {
  0% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);
  }
  60% {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
  }
}
@keyframes zoomInDown {
  0% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);
  }
  60% {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
  }
}
.zoomInDown {
  -webkit-animation-name: zoomInDown;
  animation-name: zoomInDown;
}
@-webkit-keyframes zoomInLeft {
  0% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);
  }
  60% {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);
  }
}
@keyframes zoomInLeft {
  0% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);
  }
  60% {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);
  }
}
.zoomInLeft {
  -webkit-animation-name: zoomInLeft;
  animation-name: zoomInLeft;
}
@-webkit-keyframes zoomInRight {
  0% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);
  }
  60% {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);
  }
}
@keyframes zoomInRight {
  0% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);
  }
  60% {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);
  }
}
.zoomInRight {
  -webkit-animation-name: zoomInRight;
  animation-name: zoomInRight;
}
@-webkit-keyframes zoomInUp {
  0% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);
  }
  60% {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
  }
}
@keyframes zoomInUp {
  0% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);
  }
  60% {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
  }
}
.zoomInUp {
  -webkit-animation-name: zoomInUp;
  animation-name: zoomInUp;
}
@-webkit-keyframes zoomOut {
  0% {
    opacity: 1;
  }
  50% {
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
  to {
    opacity: 0;
  }
}
@keyframes zoomOut {
  0% {
    opacity: 1;
  }
  50% {
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
  to {
    opacity: 0;
  }
}
.zoomOut {
  -webkit-animation-name: zoomOut;
  animation-name: zoomOut;
}
@-webkit-keyframes zoomOutDown {
  40% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
  }
  to {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);
    -webkit-transform-origin: center bottom;
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);
    transform-origin: center bottom;
  }
}
@keyframes zoomOutDown {
  40% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
  }
  to {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);
    -webkit-transform-origin: center bottom;
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);
    transform-origin: center bottom;
  }
}
.zoomOutDown {
  -webkit-animation-name: zoomOutDown;
  animation-name: zoomOutDown;
}
@-webkit-keyframes zoomOutLeft {
  40% {
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0);
  }
  to {
    -webkit-transform: scale(0.1) translate3d(-2000px, 0, 0);
    -webkit-transform-origin: left center;
    opacity: 0;
    transform: scale(0.1) translate3d(-2000px, 0, 0);
    transform-origin: left center;
  }
}
@keyframes zoomOutLeft {
  40% {
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0);
  }
  to {
    -webkit-transform: scale(0.1) translate3d(-2000px, 0, 0);
    -webkit-transform-origin: left center;
    opacity: 0;
    transform: scale(0.1) translate3d(-2000px, 0, 0);
    transform-origin: left center;
  }
}
.zoomOutLeft {
  -webkit-animation-name: zoomOutLeft;
  animation-name: zoomOutLeft;
}
@-webkit-keyframes zoomOutRight {
  40% {
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0);
  }
  to {
    -webkit-transform: scale(0.1) translate3d(2000px, 0, 0);
    -webkit-transform-origin: right center;
    opacity: 0;
    transform: scale(0.1) translate3d(2000px, 0, 0);
    transform-origin: right center;
  }
}
@keyframes zoomOutRight {
  40% {
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0);
  }
  to {
    -webkit-transform: scale(0.1) translate3d(2000px, 0, 0);
    -webkit-transform-origin: right center;
    opacity: 0;
    transform: scale(0.1) translate3d(2000px, 0, 0);
    transform-origin: right center;
  }
}
.zoomOutRight {
  -webkit-animation-name: zoomOutRight;
  animation-name: zoomOutRight;
}
@-webkit-keyframes zoomOutUp {
  40% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
  }
  to {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);
    -webkit-transform-origin: center bottom;
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);
    transform-origin: center bottom;
  }
}
@keyframes zoomOutUp {
  40% {
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    opacity: 1;
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
  }
  to {
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);
    -webkit-transform-origin: center bottom;
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    opacity: 0;
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);
    transform-origin: center bottom;
  }
}
.zoomOutUp {
  -webkit-animation-name: zoomOutUp;
  animation-name: zoomOutUp;
}
@-webkit-keyframes slideInDown {
  0% {
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
    visibility: visible;
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes slideInDown {
  0% {
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
    visibility: visible;
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.slideInDown {
  -webkit-animation-name: slideInDown;
  animation-name: slideInDown;
}
@-webkit-keyframes slideInLeft {
  0% {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    visibility: visible;
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes slideInLeft {
  0% {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    visibility: visible;
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.slideInLeft {
  -webkit-animation-name: slideInLeft;
  animation-name: slideInLeft;
}
@-webkit-keyframes slideInRight {
  0% {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    visibility: visible;
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes slideInRight {
  0% {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    visibility: visible;
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.slideInRight {
  -webkit-animation-name: slideInRight;
  animation-name: slideInRight;
}
@-webkit-keyframes slideInUp {
  0% {
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
    visibility: visible;
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
@keyframes slideInUp {
  0% {
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
    visibility: visible;
  }
  to {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
}
.slideInUp {
  -webkit-animation-name: slideInUp;
  animation-name: slideInUp;
}
@-webkit-keyframes slideOutDown {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  to {
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
    visibility: hidden;
  }
}
@keyframes slideOutDown {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  to {
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
    visibility: hidden;
  }
}
.slideOutDown {
  -webkit-animation-name: slideOutDown;
  animation-name: slideOutDown;
}
@-webkit-keyframes slideOutLeft {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  to {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    visibility: hidden;
  }
}
@keyframes slideOutLeft {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  to {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    visibility: hidden;
  }
}
.slideOutLeft {
  -webkit-animation-name: slideOutLeft;
  animation-name: slideOutLeft;
}
@-webkit-keyframes slideOutRight {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  to {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    visibility: hidden;
  }
}
@keyframes slideOutRight {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  to {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    visibility: hidden;
  }
}
.slideOutRight {
  -webkit-animation-name: slideOutRight;
  animation-name: slideOutRight;
}
@-webkit-keyframes slideOutUp {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  to {
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
    visibility: hidden;
  }
}
@keyframes slideOutUp {
  0% {
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
  }
  to {
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
    visibility: hidden;
  }
}
.slideOutUp {
  -webkit-animation-name: slideOutUp;
  animation-name: slideOutUp;
}
.animated {
  -webkit-animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  animation-duration: 1s;
  animation-fill-mode: both;
}
.animated.infinite {
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite;
}
.animated.delay-1s {
  -webkit-animation-delay: 1s;
  animation-delay: 1s;
}
.animated.delay-2s {
  -webkit-animation-delay: 2s;
  animation-delay: 2s;
}
.animated.delay-3s {
  -webkit-animation-delay: 3s;
  animation-delay: 3s;
}
.animated.delay-4s {
  -webkit-animation-delay: 4s;
  animation-delay: 4s;
}
.animated.delay-5s {
  -webkit-animation-delay: 5s;
  animation-delay: 5s;
}
.animated.fast {
  -webkit-animation-duration: 0.8s;
  animation-duration: 0.8s;
}
.animated.faster {
  -webkit-animation-duration: 0.5s;
  animation-duration: 0.5s;
}
.animated.slow {
  -webkit-animation-duration: 2s;
  animation-duration: 2s;
}
.animated.slower {
  -webkit-animation-duration: 3s;
  animation-duration: 3s;
}
@media (prefers-reduced-motion) {
  .animated {
    -webkit-animation: unset!important;
    -webkit-transition: none!important;
    animation: unset!important;
    transition: none !important;
  }
}
[v-cloak] > * {
  visibility: hidden;
}
[v-cloak]::before {
  content: "loading awesomeness...";
  padding: 200px 0;
  display: block;
  background: url('data:image/gif;base64,R0lGODlhEAAQAPIAAP///wAAAMLCwkJCQgAAAGJiYoKCgpKSkiH/C05FVFNDQVBFMi4wAwEAAAAh/hpDcmVhdGVkIHdpdGggYWpheGxvYWQuaW5mbwAh+QQJCgAAACwAAAAAEAAQAAADMwi63P4wyklrE2MIOggZnAdOmGYJRbExwroUmcG2LmDEwnHQLVsYOd2mBzkYDAdKa+dIAAAh+QQJCgAAACwAAAAAEAAQAAADNAi63P5OjCEgG4QMu7DmikRxQlFUYDEZIGBMRVsaqHwctXXf7WEYB4Ag1xjihkMZsiUkKhIAIfkECQoAAAAsAAAAABAAEAAAAzYIujIjK8pByJDMlFYvBoVjHA70GU7xSUJhmKtwHPAKzLO9HMaoKwJZ7Rf8AYPDDzKpZBqfvwQAIfkECQoAAAAsAAAAABAAEAAAAzMIumIlK8oyhpHsnFZfhYumCYUhDAQxRIdhHBGqRoKw0R8DYlJd8z0fMDgsGo/IpHI5TAAAIfkECQoAAAAsAAAAABAAEAAAAzIIunInK0rnZBTwGPNMgQwmdsNgXGJUlIWEuR5oWUIpz8pAEAMe6TwfwyYsGo/IpFKSAAAh+QQJCgAAACwAAAAAEAAQAAADMwi6IMKQORfjdOe82p4wGccc4CEuQradylesojEMBgsUc2G7sDX3lQGBMLAJibufbSlKAAAh+QQJCgAAACwAAAAAEAAQAAADMgi63P7wCRHZnFVdmgHu2nFwlWCI3WGc3TSWhUFGxTAUkGCbtgENBMJAEJsxgMLWzpEAACH5BAkKAAAALAAAAAAQABAAAAMyCLrc/jDKSatlQtScKdceCAjDII7HcQ4EMTCpyrCuUBjCYRgHVtqlAiB1YhiCnlsRkAAAOwAAAAAAAAAAAA==') no-repeat center 40%;
}
.seedprodloading > * {
  visibility: hidden;
}
.seedprodloading::before {
  content: "loading awesomeness...";
  padding: 200px 0;
  display: block;
  background: url('data:image/gif;base64,R0lGODlhEAAQAPIAAP///wAAAMLCwkJCQgAAAGJiYoKCgpKSkiH/C05FVFNDQVBFMi4wAwEAAAAh/hpDcmVhdGVkIHdpdGggYWpheGxvYWQuaW5mbwAh+QQJCgAAACwAAAAAEAAQAAADMwi63P4wyklrE2MIOggZnAdOmGYJRbExwroUmcG2LmDEwnHQLVsYOd2mBzkYDAdKa+dIAAAh+QQJCgAAACwAAAAAEAAQAAADNAi63P5OjCEgG4QMu7DmikRxQlFUYDEZIGBMRVsaqHwctXXf7WEYB4Ag1xjihkMZsiUkKhIAIfkECQoAAAAsAAAAABAAEAAAAzYIujIjK8pByJDMlFYvBoVjHA70GU7xSUJhmKtwHPAKzLO9HMaoKwJZ7Rf8AYPDDzKpZBqfvwQAIfkECQoAAAAsAAAAABAAEAAAAzMIumIlK8oyhpHsnFZfhYumCYUhDAQxRIdhHBGqRoKw0R8DYlJd8z0fMDgsGo/IpHI5TAAAIfkECQoAAAAsAAAAABAAEAAAAzIIunInK0rnZBTwGPNMgQwmdsNgXGJUlIWEuR5oWUIpz8pAEAMe6TwfwyYsGo/IpFKSAAAh+QQJCgAAACwAAAAAEAAQAAADMwi6IMKQORfjdOe82p4wGccc4CEuQradylesojEMBgsUc2G7sDX3lQGBMLAJibufbSlKAAAh+QQJCgAAACwAAAAAEAAQAAADMgi63P7wCRHZnFVdmgHu2nFwlWCI3WGc3TSWhUFGxTAUkGCbtgENBMJAEJsxgMLWzpEAACH5BAkKAAAALAAAAAAQABAAAAMyCLrc/jDKSatlQtScKdceCAjDII7HcQ4EMTCpyrCuUBjCYRgHVtqlAiB1YhiCnlsRkAAAOwAAAAAAAAAAAA==') no-repeat center 40%;
}
.iframe_loading {
  background-image: url('data:image/gif;base64,R0lGODlhEAAQAPIAAP///wAAAMLCwkJCQgAAAGJiYoKCgpKSkiH/C05FVFNDQVBFMi4wAwEAAAAh/hpDcmVhdGVkIHdpdGggYWpheGxvYWQuaW5mbwAh+QQJCgAAACwAAAAAEAAQAAADMwi63P4wyklrE2MIOggZnAdOmGYJRbExwroUmcG2LmDEwnHQLVsYOd2mBzkYDAdKa+dIAAAh+QQJCgAAACwAAAAAEAAQAAADNAi63P5OjCEgG4QMu7DmikRxQlFUYDEZIGBMRVsaqHwctXXf7WEYB4Ag1xjihkMZsiUkKhIAIfkECQoAAAAsAAAAABAAEAAAAzYIujIjK8pByJDMlFYvBoVjHA70GU7xSUJhmKtwHPAKzLO9HMaoKwJZ7Rf8AYPDDzKpZBqfvwQAIfkECQoAAAAsAAAAABAAEAAAAzMIumIlK8oyhpHsnFZfhYumCYUhDAQxRIdhHBGqRoKw0R8DYlJd8z0fMDgsGo/IpHI5TAAAIfkECQoAAAAsAAAAABAAEAAAAzIIunInK0rnZBTwGPNMgQwmdsNgXGJUlIWEuR5oWUIpz8pAEAMe6TwfwyYsGo/IpFKSAAAh+QQJCgAAACwAAAAAEAAQAAADMwi6IMKQORfjdOe82p4wGccc4CEuQradylesojEMBgsUc2G7sDX3lQGBMLAJibufbSlKAAAh+QQJCgAAACwAAAAAEAAQAAADMgi63P7wCRHZnFVdmgHu2nFwlWCI3WGc3TSWhUFGxTAUkGCbtgENBMJAEJsxgMLWzpEAACH5BAkKAAAALAAAAAAQABAAAAMyCLrc/jDKSatlQtScKdceCAjDII7HcQ4EMTCpyrCuUBjCYRgHVtqlAiB1YhiCnlsRkAAAOwAAAAAAAAAAAA==') !important;
  background-repeat: no-repeat !important;
  background-position: center 100px  !important;
}
.btn-file input[type=file] {
  outline: none !important;
}
@media screen and (-webkit-min-device-pixel-ratio: 0) {
  select,
  textarea,
  input {
    font-size: 16px !important;
  }
}
.seedprod-page body {
  padding-top: 10px;
  padding-bottom: 10px;
  background-size: cover;
  background-repeat: no-repeat;
  background-position: center top;
  background-attachment: fixed;
}
#seedprod-wrapper {
  background: #fff;
  max-width: 480px;
  margin: auto;
  text-align: center;
  border-radius: 6px;
  color: #696969;
  background-color: #fbfbfb;
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
          box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}
.seedprod-page .btn-default {
  margin-bottom: 0px;
  padding: 10px;
}
#seedprod-page-entries .active {
  background: #fff;
  color: #222;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  border-bottom: none;
  margin-bottom: 0;
  -webkit-box-shadow: none !important;
          box-shadow: none !important;
}
.dim {
  opacity: 0.65;
}
.seedprod-action {
  background: #fff;
  font-size: 13px;
  padding: 10px 25px;
  margin-bottom: 1px;
  border-top: none;
  text-align: left;
}
.seedprod-page .col-xs-4 {
  width: 33%;
}
.seedprod-page .btn-action[disabled] {
  border: 1px dashed rgba(69, 87, 112, 0.4);
  background: rgba(0, 0, 0, 0.05);
}
.pl-10 {
  padding-left: 10px;
}
#seedprod-credit-logo {
  width: 16px;
  margin-right: 5px;
  vertical-align: bottom;
}
#seedprod-countdown,
#seedprod-total-entries,
#seedprod-my-entires {
  text-align: center;
  display: table;
  width: 100%;
  min-height: 40px;
}
.seedprod-terms-consent {
  padding: 0 40px;
}
.seedprod-terms-consent label {
  font-weight: normal;
  font-size: 12px;
  line-height: 1.3;
}
#seedprod-countdown {
  font-size: 16px;
}
.seedprod-td {
  display: table-cell;
  vertical-align: middle;
  padding: 0 3px;
  height: 68px;
}
.seedprod-top-sep {
  border-right: 1px solid #f2f2f2;
}
.seedprod-over-txt {
  font-size: 20px;
  line-height: 0.9;
  font-weight: bold;
  margin-bottom: 5px;
  display: inline-block;
}
.seedprod-under-txt {
  font-size: 12px;
  line-height: 1;
  display: block;
}
.seedprod-page .equal {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  display: -webkit-flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
}
.seedprod-page .no-pad {
  margin-right: 0;
  margin-left: 0;
}
.seedprod-page .no-pad > [class*='col-'] {
  padding-right: 0;
  padding-left: 0;
}
#seedprod-page-form {
  background: #fff;
  border-bottom: 1px solid #f2f2f2;
  padding: 5px;
}
#seedprod-prize-info {
  background: #fff;
  border-top: 1px solid #f2f2f2;
}
#seedprod-prize-info h1 {
  margin: 0;
  margin-top: 30px;
  margin-bottom: 10px;
  font-size: 24px;
  color: #2d2d2d;
  font-weight: 700;
}
p {
  font-size: 13px;
  line-height: 1.5;
  margin: 1em 0;
}
#seedprod-header {
  margin: 0;
  padding: 0 40px;
  margin-bottom: 12px;
  font-size: 16px;
  line-height: 1.4;
  color: #666;
}
.slider-btn-left {
  background: transparent !important;
}
.slider-btn-right {
  background: transparent !important;
}
#seedprod-page-login {
  padding: 15px 0;
  font-size: 14px;
  color: #666;
}
#seedprod-page-entries p > strong {
  font-size: 16px;
  color: #2d2d2d;
}
#seedprod-page-entries p {
  margin-bottom: 11px;
}
#seedprod-page-entries {
  border-bottom: 1px solid #f2f2f2;
  padding: 11px 0px 0px 0px;
  color: #2d2d2d;
}
#seedprod-page-entries .btn {
  outline: none;
}
#seedprod-page-entries .btn-action {
  font-size: 16px;
  font-weight: normal;
  position: relative;
  padding-top: 20px;
  padding-bottom: 20px;
  padding-left: 74px;
  color: #707070;
  text-align: left;
  overflow: hidden;
  text-overflow: ellipsis;
  padding-right: 60px;
}
#seedprod-page-footer {
  padding: 15px 20px;
  font-size: 11px;
}
#seedprod-page-footer a {
  color: #9c9c9c !important;
}
#seedprod-page-rules {
  padding-top: 20px;
  font-size: 11px;
}
.slider-icon {
  -webkit-box-shadow: rgba(0, 0, 0, 0.2) -1px 1px 0px;
          box-shadow: rgba(0, 0, 0, 0.2) -1px 1px 0px;
}
.slider-indicator-icon {
  -webkit-box-shadow: rgba(255, 255, 255, 0.76) 0 0 2px;
          box-shadow: rgba(255, 255, 255, 0.76) 0 0 2px;
}
.slider-indicator-active {
  -webkit-box-shadow: rgba(0, 0, 0, 0.76) 0 0 2px;
          box-shadow: rgba(0, 0, 0, 0.76) 0 0 2px;
}
.slider-indicator-icon {
  background-color: rgba(0, 0, 0, 0.6) !important;
}
.slider-indicator-active {
  background-color: rgba(255, 255, 255, 0.9) !important;
}
.tooltip {
  display: block !important;
  z-index: 10000;
}
.tooltip .tooltip-inner {
  background: black;
  color: white;
  border-radius: 16px;
  padding: 10px 10px 10px;
}
.tooltip .tooltip-arrow {
  width: 0;
  height: 0;
  border-style: solid;
  position: absolute;
  margin: 5px;
  border-color: black;
}
.tooltip[x-placement^="top"] {
  margin-bottom: 5px;
}
.tooltip[x-placement^="top"] .tooltip-arrow {
  border-width: 5px 5px 0 5px;
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-bottom-color: transparent !important;
  bottom: -5px;
  left: calc(50% - 5px);
  margin-top: 0;
  margin-bottom: 0;
}
.tooltip[x-placement^="bottom"] {
  margin-top: 5px;
}
.tooltip[x-placement^="bottom"] .tooltip-arrow {
  border-width: 0 5px 5px 5px;
  border-left-color: transparent !important;
  border-right-color: transparent !important;
  border-top-color: transparent !important;
  top: -5px;
  left: calc(50% - 5px);
  margin-top: 0;
  margin-bottom: 0;
}
.tooltip[x-placement^="right"] {
  margin-left: 5px;
}
.tooltip[x-placement^="right"] .tooltip-arrow {
  border-width: 5px 5px 5px 0;
  border-left-color: transparent !important;
  border-top-color: transparent !important;
  border-bottom-color: transparent !important;
  left: -5px;
  top: calc(50% - 5px);
  margin-left: 0;
  margin-right: 0;
}
.tooltip[x-placement^="left"] {
  margin-right: 5px;
}
.tooltip[x-placement^="left"] .tooltip-arrow {
  border-width: 5px 0 5px 5px;
  border-top-color: transparent !important;
  border-right-color: transparent !important;
  border-bottom-color: transparent !important;
  right: -5px;
  top: calc(50% - 5px);
  margin-left: 0;
  margin-right: 0;
}
.tooltip[aria-hidden='true'] {
  visibility: hidden;
  opacity: 0;
  -webkit-transition: opacity 0.15s, visibility 0.15s;
  transition: opacity 0.15s, visibility 0.15s;
}
.tooltip[aria-hidden='false'] {
  visibility: visible;
  opacity: 1;
  -webkit-transition: opacity 0.15s;
  transition: opacity 0.15s;
}
.seedprod-page .share_facebook {
  background-color: #4267b2;
  color: #fff;
  border-radius: 3px;
  width: 40px;
  display: inline-block;
  padding: 4px 10px;
}
.seedprod-page .share_twitter {
  background-color: #38A1F3;
  color: #fff;
  border-radius: 3px;
  width: 40px;
  display: inline-block;
  padding: 4px 10px;
}
.seedprod-page .share_pinterest {
  background-color: #e60023;
  color: #fff;
  border-radius: 3px;
  width: 40px;
  display: inline-block;
  padding: 4px 10px;
}
.seedprod-page .share_linkedin {
  background-color: #0077B5;
  color: #fff;
  border-radius: 3px;
  width: 40px;
  display: inline-block;
  padding: 4px 10px;
}
.seedprod-page .share_email {
  background-color: #e05446;
  color: #fff;
  border-radius: 3px;
  width: 40px;
  display: inline-block;
  padding: 4px 10px;
}
.seedprod-page .share_facebook:hover,
.seedprod-page .share_twitter:hover,
.seedprod-page .share_linkedin:hover,
.seedprod-page .share_pinterest:hover,
.seedprod-page .share_email:hover,
.seedprod-page .share_facebook:focus,
.seedprod-page .share_twitter:focus,
.seedprod-page .share_linkedin:focus,
.seedprod-page .share_pinterest:focus,
.seedprod-page .share_email:focus {
  color: #fff;
}
.seedprod-highlight-option-target {
  -webkit-box-shadow: inset 0 0 1px 1px #f3510b;
          box-shadow: inset 0 0 1px 1px #f3510b;
  position: relative;
  cursor: pointer;
  -webkit-animation-name: hightlight_pulse_color;
          animation-name: hightlight_pulse_color;
  -webkit-animation-duration: 1.5s;
          animation-duration: 1.5s;
  -webkit-animation-iteration-count: infinite;
          animation-iteration-count: infinite;
  -webkit-animation-timing-function: ease;
          animation-timing-function: ease;
}
@-webkit-keyframes hightlight_pulse_color {
  0% {
    -webkit-box-shadow: inset 0 0 1px 1px #f3510b;
            box-shadow: inset 0 0 1px 1px #f3510b;
  }
  50% {
    -webkit-box-shadow: inset 0 0 1px 1px #fff;
            box-shadow: inset 0 0 1px 1px #fff;
  }
  100% {
    -webkit-box-shadow: inset 0 0 1px 1px #f3510b;
            box-shadow: inset 0 0 1px 1px #f3510b;
  }
}
@keyframes hightlight_pulse_color {
  0% {
    -webkit-box-shadow: inset 0 0 1px 1px #f3510b;
            box-shadow: inset 0 0 1px 1px #f3510b;
  }
  50% {
    -webkit-box-shadow: inset 0 0 1px 1px #fff;
            box-shadow: inset 0 0 1px 1px #fff;
  }
  100% {
    -webkit-box-shadow: inset 0 0 1px 1px #f3510b;
            box-shadow: inset 0 0 1px 1px #f3510b;
  }
}
.seedprod-page .form-inline .form-control {
  display: inline-block;
  width: auto;
  vertical-align: middle;
}
@media (max-width: 480px) {
  .seedprod-page .form-inline .form-control {
    display: block;
    margin-bottom: 10px !important;
    width: 80% !important;
    margin: auto !important;
  }
  .seedprod-page .form-inline .btn-primary {
    display: block;
    width: 80%;
    margin: auto !important;
  }
}
#seedprod-page-login .btn {
  padding: 9px 20px;
}
#seedprod-page-login .form-control {
  height: 40px;
  margin-right: 8px;
  width: 165px;
}
#seedprod-social-profiles li a {
  color: #fff !important;
}
#seedprod-container-fluid {
  padding-left: 3px;
  padding-right: 3px;
}
.seedprod-action-text {
  white-space: normal;
}
#seedprod-login-options {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
}
#seedprod-login-fb {
  margin-top: 10px;
  padding-right: 10px;
}
#seedprod-login-email {
  margin-top: 10px;
}
@media (max-width: 400px) {
  #seedprod-login-options {
    display: block;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
  }
  #seedprod-login-fb {
    padding-right: 0px;
  }
  #seedprod-login-fb iframe body {
    text-align: center;
  }
  #seedprod-login-email {
    padding-left: 0px;
  }
  .seedprod-action-text {
    font-size: 13px;
  }
}
.seedprod-page .alert {
  background: #444;
  color: #fff;
  border: none;
  border-radius: 0;
  font-weight: bold;
  margin-bottom: 0;
  position: relative;
}
.seedprod-close-alert {
  position: absolute;
  top: 0px;
  right: 5px;
  cursor: pointer;
  opacity: 0.7;
}
#seedprod-winners {
  padding: 15px;
}
#seedprod-winners strong {
  font-size: 24px;
  color: #2d2d2d;
  margin-bottom: 10px;
  display: inline-block;
}
#seedprod-winners img {
  border-radius: 6px;
}
#seedprod-winners li {
  padding: 5px 0;
}
.seedprod-page .btn-question {
  background-color: #9900bb !important;
  border-color: #9900bb !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-invent-your-own {
  background-color: #0f0f0f !important;
  border-color: #0f0f0f !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-refer-a-friend {
  background-color: #e42e2f !important;
  border-color: #e42e2f !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-automatic-entry {
  background-color: #FF9800 !important;
  border-color: #FF9800 !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-submit-image {
  background-color: #009688 !important;
  border-color: #009688 !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-polls-surveys {
  background-color: #E91E63 !important;
  border-color: #E91E63 !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-visit-a-page {
  background-color: #0000ba !important;
  border-color: #0000ba !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-join-newsletter {
  background-color: #4caf50 !important;
  border-color: #4caf50 !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-facebook {
  background-color: #4267b2 !important;
  border-color: #4267b2 !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-twitter {
  background-color: #1b95e0 !important;
  border-color: #1b95e0 !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-instagram {
  background-color: #f55f3f !important;
  border-color: #f55f3f !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
  font-weight: normal !important;
}
.seedprod-page .btn-pinterest {
  background: #e60023 !important;
  border-color: #e60023 !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
}
.fa-pinterest {
  color: #fff;
}
.seedprod-page .btn-youtube {
  background: #ff0000 !important;
  border-color: #ff0000 !important;
  color: #fff !important;
  font-family: "Helvetica Neue", Arial, sans-serif !important;
}
.seedprod-action p {
  font-size: 14px;
}
#seedprod-page-rules textarea {
  overflow-y: scroll;
  height: 100px;
  resize: none;
  font-size: 13px;
}
.seedprod-page .btn-default.active {
  border-color: #f2f2f2;
}
.seedprod-page .btn-default {
  background: #fff !important;
  border-color: #f2f2f2 !important;
  color: #707070;
  border-left: none;
  border-right: none;
  border-bottom: none;
  border-radius: 0;
  -webkit-box-shadow: none !important;
          box-shadow: none !important;
}
.seedprod-page .list-inline {
  text-align: center;
}
.seedprod-block-option-value {
  border: 1px solid #f2f2f2;
  color: #9b9b9b;
  padding: 2px;
  padding-top: 5px;
  width: 30px;
  height: 30px;
  right: 24px;
  position: absolute;
  top: 50%;
  -webkit-transform: translateY(-50%);
          transform: translateY(-50%);
  font-size: 13px;
  text-align: center;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
}
.seedprod-action-arrow {
  padding-left: 5px;
}
.seedprod-action-check {
  padding-left: 5px;
}
.seedprod-facebook-responsive {
  overflow: hidden;
  position: relative;
}
.seedprod-facebook-responsive span {
  width: 100% !important;
}
.seedprod-facebook-responsive iframe {
  width: 100% !important;
}
.seedprod-block-option-desc {
  font-size: 11px;
  color: #9b9b9b;
  margin-top: 3px;
}
.seedprod-block-option-desc-daily {
  font-size: 11px;
  color: #9b9b9b;
  margin-top: 3px;
  position: static;
  width: 100%;
  display: block;
}
.seedprod-block-option-icon {
  border: 1px solid #f2f2f2;
  padding: 2px;
  padding-left: 3px;
  padding-top: 4px;
  width: 29px;
  height: 29px;
  left: 24px;
  position: absolute;
  top: 50%;
  -webkit-transform: translateY(-50%);
          transform: translateY(-50%);
  font-size: 14px;
  text-align: center;
}
.seedprod-block-option-icon::before {
  -webkit-font-smoothing: antialiased;
}
.seedprod-icon::before {
  display: inline-block;
  font-style: normal;
  font-variant: normal;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
}
.icon-refer-a-friend::before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f004";
}
.icon-refer-a-friend {
  background-color: #e42e2f;
  border-color: #e42e2f !important;
  color: #fff;
}
.icon-automatic-entry::before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f3ff";
}
.icon-automatic-entry {
  background-color: #FF9800;
  border-color: #FF9800 !important;
  color: #fff;
}
.icon-submit-image::before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f03e";
}
.icon-submit-image {
  background-color: #009688;
  border-color: #009688 !important;
  color: #fff;
}
.icon-polls-surveys::before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f681";
}
.icon-polls-surveys {
  background-color: #E91E63;
  border-color: #E91E63 !important;
  color: #fff;
}
.icon-join-newsletter {
  background-color: #4CAF50;
  border-color: #4CAF50 !important;
  color: #fff;
}
.icon-join-newsletter::before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f0e0";
}
.icon-visit-a-page::before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f35d";
}
.icon-visit-a-page {
  background-color: #0000ba;
  border-color: #0000ba !important;
  color: #fff;
}
.icon-visit-fb::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f09a";
}
.icon-visit-fb {
  background-color: #4267b2;
  border-color: #4267b2 !important;
  color: #fff;
}
.icon-fb-page-post::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f09a";
}
.icon-fb-page-post {
  background-color: #4267b2;
  border-color: #4267b2 !important;
  color: #fff;
}
.icon-tweet::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f099";
}
.icon-tweet {
  background-color: #38A1F3;
  border-color: #38A1F3 !important;
  color: #fff;
}
.icon-twitter-follow::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f099";
}
.icon-twitter-follow {
  background-color: #38A1F3;
  border-color: #38A1F3 !important;
  color: #fff;
}
.icon-instagram-follow::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f16d";
}
.icon-instagram-follow {
  background-color: #f55f3f;
  border-color: #f55f3f !important;
  color: #fff;
}
.icon-instagram-page-post::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f16d";
}
.icon-instagram-page-post {
  background-color: #f55f3f;
  border-color: #f55f3f !important;
  color: #fff;
}
.icon-pinterest-follow::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f0d2";
}
.icon-pinterest-follow {
  background-color: #e60023;
  border-color: #e60023 !important;
  color: #fff;
}
.icon-youtube-follow::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f167";
}
.icon-youtube-follow {
  background-color: #ff0000;
  border-color: #ff0000 !important;
  color: #fff;
}
.icon-watch-a-video::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
  content: "\f167";
}
.icon-watch-a-video {
  background-color: #ff0000;
  border-color: #ff0000 !important;
  color: #fff;
}
.icon-question::before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f059";
}
.icon-question {
  background-color: #9900bb;
  border-color: #9900bb !important;
  color: #fff;
}
.icon-invent-your-own::before {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
  content: "\f0eb";
}
.icon-invent-your-own {
  background-color: #0f0f0f;
  border-color: #0f0f0f !important;
  color: #fff;
}
.fb_iframe_widget {
  width: 100%;
  margin: 16px 0px !important;
}
.fb-like > span .iframe {
  text-align: center !important;
}
#login-ft-txt {
  margin-top: 15px;
  font-size: 12px;
  text-align: center;
}
#u_0_0 {
  width: 100% !important;
}
.fb-like,
.fb-like > span,
.fb-like > span > iframe {
  width: 100% !important;
}
.form-inline {
  margin-top: 10px;
}
.layout-3 .slider-indicators {
  top: 9px !important;
}
.seedprod-50 {
  width: 49% !important;
}
.entry-error {
  color: red;
  display: block;
  font-size: 13px;
  margin-top: 3px;
}
#seedprod-bonus-entries {
  background: #fff;
  border: 1px solid #f2f2f2;
  border-radius: 4px;
  margin: 10px;
  padding: 10px;
}
.seedprod-upload {
  line-height: 1;
}
.seedprod-action .radio label {
  line-height: 2;
}
.seedprod-action .checkbox label {
  line-height: 2;
}

/*# sourceMappingURL=data:application/json;charset=utf8;base64,  */

/*# sourceMappingURL=seedprod-style.css.map */
